@@ -8,7 +8,7 @@ from dask_kubernetes.aiopykube.objects import Pod
 
 
 @pytest.mark.asyncio
-async def test_pod_create_and_delete(k8s_cluster):
+async def test_pod_create_and_delete(docker_image, k8s_cluster):
     api = HTTPClient(KubeConfig.from_env())
     name = "test-" + uuid.uuid4().hex[:10]
     pod = Pod(
@@ -19,7 +19,13 @@ async def test_pod_create_and_delete(k8s_cluster):
             "metadata": {"name": name},
             "spec": {
                 "containers": [
-                    {"name": "pause", "image": "gcr.io/google_containers/pause"}
+                    # Cannot use `gcr.io/google_containers/pause` as it's not available
+                    # for arm64
+                    {
+                        "name": "pause",
+                        "image": docker_image,
+                        "command": ["sleep", "1000"],
+                    },
                 ]
             },
         },
